@@ -15,7 +15,7 @@ from selenium.webdriver.support.ui import Select
 from selenium.webdriver.support.wait import WebDriverWait
 
 from poe import aspect
-from poe import logger
+from poe.logger import logger
 from poe.utility import get_methods_and_properties
 
 
